==> nextcloud-app-news-14.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/eo.js <==
OC.L10N.register(
    "news",
    {
    "Can not add feed: Exists already" : "Ne eblas aldoni fluon: ĝi jam ekzistas",
    "Can not add folder: Exists already" : "Ne eblas aldoni dosierujon: ĝi jam ekzistas",
    "News" : "Novaĵo",
    "Saved" : "Konservita",
    "Download" : "Elŝuti",
    "Close" : "Fermi",
    "Language" : "Lingvo",
    "Subscribe" : "Aboni",
    "Open website" : "Malfermi TTT-ejon",
    "by" : "de",
    "from" : "el",
    "Description" : "Priskribo",
    "right" : "dekstro",
    "left" : "maldekstro",
    "Refresh" : "Refreŝigi",
    "Web address" : "TTT-adreso",
    "Folder" : "Dosierujo",
    "No folder" : "Neniu dosierujo",
    "New folder" : "Nova dosierujo",
    "Folder name" : "Dosierujnomo",
    "Go back" : "Revenu",
    "Folder exists already!" : "Dosierujo jam ekzistas!",
    "Credentials" : "Aŭtentigiloj",
    "Username" : "Uzantonomo",
    "Password" : "Pasvorto",
    "New Folder" : "Nova dosierujo",
    "Create" : "Krei",
    "Deleted feed" : "Forigis fluon",
    "Undo delete feed" : "Malfari forigon de fluo",
    "Rename" : "Alinomigi",
    "Mark read" : "Marki kiel legita",
    "Delete" : "Forigi",
    "Dismiss" : "Forsendi",
    "Collapse" : "Maletendi",
    "Deleted folder" : "Foriĝis dosierujo",
    "Undo delete folder" : "Malfari forigon de dosierujo",
    "Starred" : "Markita",
    "Unread articles" : "Nelegitaj artikoloj",
    "All articles" : "Ĉiuj artikoloj",
    "Settings" : "Agordo",
    "Show all articles" : "Montri ĉiujn artikolojn",
    "Import" : "Enporti",
    "Export" : "Elporti",
    "Error when importing: file does not contain valid JSON" : "La enporto eraris: la dosiero ne enhavas validan JSON-on",
    "Help" : "Helpo",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Documentation" : "Dokumentaro"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-14.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/eo.js <==
OC.L10N.register(
    "news",
    {
    "Can not add feed: Exists already" : "Ne eblas aldoni fluon: ĝi jam ekzistas",
    "Can not add folder: Exists already" : "Ne eblas aldoni dosierujon: ĝi jam ekzistas",
    "News" : "Novaĵo",
    "Saved" : "Konservita",
    "Download" : "Elŝuti",
    "Close" : "Fermi",
    "Language" : "Lingvo",
    "Subscribe" : "Aboni",
    "Open website" : "Malfermi TTT-ejon",
    "by" : "de",
    "from" : "el",
    "Description" : "Priskribo",
    "right" : "dekstro",
    "left" : "maldekstro",
    "Refresh" : "Refreŝigi",
    "Web address" : "TTT-adreso",
    "Folder" : "Dosierujo",
    "No folder" : "Neniu dosierujo",
    "New folder" : "Nova dosierujo",
    "Folder name" : "Dosierujnomo",
    "Go back" : "Revenu",
    "Folder exists already!" : "Dosierujo jam ekzistas!",
    "Credentials" : "Aŭtentigiloj",
    "Username" : "Uzantonomo",
    "Password" : "Pasvorto",
    "New Folder" : "Nova dosierujo",
    "Create" : "Krei",
    "Deleted feed" : "Forigis fluon",
    "Undo delete feed" : "Malfari forigon de fluo",
    "Rename" : "Alinomigi",
    "Mark read" : "Marki kiel legita",
    "Newest first" : "Pli novaj unue",
    "Oldest first" : "Malpli novaj unue",
    "Delete" : "Forigi",
    "Dismiss" : "Forsendi",
    "Collapse" : "Maletendi",
    "Deleted folder" : "Foriĝis dosierujo",
    "Undo delete folder" : "Malfari forigon de dosierujo",
    "Starred" : "Markita",
    "Unread articles" : "Nelegitaj artikoloj",
    "All articles" : "Ĉiuj artikoloj",
    "Settings" : "Agordo",
    "Show all articles" : "Montri ĉiujn artikolojn",
    "Import" : "Enporti",
    "Export" : "Elporti",
    "Error when importing: file does not contain valid JSON" : "La enporto eraris: la dosiero ne enhavas validan JSON-on",
    "Help" : "Helpo",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Documentation" : "Dokumentaro",
    "Report a bug" : "Raporti problemon"
},
"nplurals=2; plural=(n != 1);");
